@@ -8,7 +8,7 @@ struct mapped_region {
     size_t length;
 };
 
-int map_file(const char *pathname, struct mapped_region *mapped_region, char mode);
+int map_file(const char *pathname, struct mapped_region *mapped_region);
 
 int unmap_file(struct mapped_region *mapped_region);
 
